@@ -30,18 +30,11 @@
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
 
-  #:use-module (ice-9 curried-definitions)
-  #:use-module (ice-9 getopt-long)
-  #:use-module (ice-9 match)
-  #:use-module (ice-9 optargs)
-
   #:use-module (dzn ast goops)
   #:use-module (dzn ast)
   #:use-module (dzn code-util)
   #:use-module (dzn config)
-  #:use-module (dzn indent)
   #:use-module (dzn misc)
-  #:use-module (dzn shell-util)
   #:use-module (dzn templates)
 
   #:export (ast->dzn
