@@ -58,7 +58,6 @@
             assert-illegal
             assert-livelock
             assert-nondeterministic
-            assert-unreachable
             aut-text->lts
             cleanup-aut
             cleanup-error
@@ -72,6 +71,7 @@
             lts->rtc-lts
             lts->traces
             lts-hide
+            lts->tags
             make-shared-string
             node?
             node-edges
@@ -351,7 +351,8 @@
 
 (define (assert-livelock lts)
   "Trace to entry point of first livelock or #f if no tau loops found"
-  (let* ((livelock-nodes (lts-tau-loops lts))
+  (let* ((lts (remove-tag-loops lts))
+         (livelock-nodes (lts-tau-loops lts))
          (loop-entry-trace (and (pair? livelock-nodes)
                                 (trace lts (car livelock-nodes))))
          (loop-entry-node (and loop-entry-trace (car livelock-nodes)))
@@ -384,6 +385,19 @@
   (let ((lts (annotate-exclude lts (list %<declarative-illegal> %<illegal>))))
     (vector-map-one exclude lts)))
 
+
+;;;
+;;; Tag
+;;;
+(define (remove-tag-loops lts)
+  (define (tag-edge? edge)
+    (and (string-contains (edge-label edge) "tag(")
+         (= (edge-from edge) (edge-to edge))))
+  (define (remove-tag node)
+    (let ((edges (filter (negate tag-edge?) (node-edges node))))
+      (set-field node (node-edges) edges)))
+  (vector-map-one remove-tag lts))
+
 
 ;;;
 ;;; Deadlock.
@@ -398,7 +412,8 @@
 
 (define (deadlock-nodes lts)
   "States without outgoing edges"
-  (let* ((lts (remove-state-edges lts))
+  (let* ((lts (remove-tag-loops lts))
+         (lts (remove-state-edges lts))
          (lts (annotate-exclude lts (list %<declarative-illegal>))))
     (define (edges? state)
       (let ((node (vector-ref lts state)))
@@ -417,16 +432,12 @@
                               (trace lts (car deadlock-nodes)))))
     deadlock-trace))
 
-(define (assert-unreachable lts tags)
-  "Return any TAGS that are not present in LTS."
+(define (lts->tags lts)
+  "Return TAGS present in LTS."
   (let* ((edges (append-map node-edges (vector->list lts)))
          (labels (map edge-label edges))
-         (lts-tages (filter (cut string-prefix? "tag(" <>) labels))
-         (lts-tages (delete-duplicates lts-tages))
-         (missing-tags (filter (negate (cut member <> lts-tages)) tags))
-         (missing-tags (delete-duplicates missing-tags)))
-    (if (null? missing-tags) #f
-        missing-tags)))
+         (tags (delete-duplicates (filter (cut string-prefix? "tag(" <>) labels))))
+    tags))
 
 (define (illegal-nodes lts)
   "States with labels of illegal outgoing edges."
