@@ -36,32 +36,24 @@
   #:use-module (gnu packages maths)
   #:use-module (gnu packages pkg-config))
 
-(define %source-dir (getcwd))
-
-;; scp kluit.dezyne.org:.../download/dezyne-2.10.0.tar.gz .
-;; guix download ./dezyne-2.10.0.tar.gz
-
-;; This makes `git am 0001-guix-dezyne-Update-to-2.13.2.patch' work.
-(define guile-3.0-latest guile-next)
-
 (define-public dezyne
   (package
     (name "dezyne")
-    (version #!dezyne!# "2.17.4")
+    (version #!dezyne!# "2.17.5")
     (source
      (origin
        (method url-fetch)
        (uri (string-append "https://dezyne.org/download/dezyne/"
                            name "-" version ".tar.gz"))
        (sha256
-        (base32 #!dezyne!# "0kqcc6rx3sx7l3wrwp59gdj40ycaaa7s450in6y8g3vdbx2vv80h"))))
+        (base32 #!dezyne!# "15jhi17f0aqnlznvpf6lkz2y837xkzf8chi9rhhb55920vqf6cgg"))))
     (inputs (list bash-minimal
-                  guile-3.0-latest
+                  guile-3.0
                   guile-json-4
                   guile-readline
                   mcrl2-minimal
                   sed))
-    (native-inputs (list guile-3.0-latest pkg-config))
+    (native-inputs (list guile-3.0 pkg-config))
     (build-system gnu-build-system)
     (arguments
      (list
@@ -73,21 +65,19 @@
             (lambda _
               (setenv "GUILE_AUTO_COMPILE" "0")))
           (add-after 'install 'install-readmes
-            (lambda* (#:key outputs #:allow-other-keys)
-              (let* ((out (assoc-ref outputs "out"))
-                     (base (string-append #$name "-" #$version))
-                     (doc (string-append out "/share/doc/" base)))
+            (lambda _
+              (let* ((base (string-append #$name "-" #$version))
+                     (doc (string-append #$output "/share/doc/" base)))
                 (mkdir-p doc)
                 (copy-file "NEWS" (string-append doc "/NEWS")))))
           (add-after 'install 'wrap-binaries
-            (lambda* (#:key inputs outputs #:allow-other-keys)
-              (let* ((out (assoc-ref outputs "out"))
-                     (bash (assoc-ref %build-inputs "bash-minimal"))
-                     (guile (assoc-ref %build-inputs "guile-next"))
-                     (json (assoc-ref %build-inputs "guile-json"))
-                     (mcrl2 (assoc-ref %build-inputs "mcrl2-minimal"))
-                     (readline (assoc-ref %build-inputs "guile-readline"))
-                     (sed (assoc-ref %build-inputs "sed"))
+            (lambda _
+              (let* ((bash #$(this-package-input "bash-minimal"))
+                     (guile #$(this-package-input "guile-3.0"))
+                     (json #$(this-package-input "guile-json"))
+                     (mcrl2 #$(this-package-input "mcrl2-minimal"))
+                     (readline #$(this-package-input "guile-readline"))
+                     (sed #$(this-package-input "sed"))
                      (effective (read
                                  (open-pipe* OPEN_READ
                                              "guile" "-c"
@@ -98,15 +88,15 @@
                                  (string-append sed "/bin")))
                      (scm-dir (string-append "/share/guile/site/" effective))
                      (scm-path
-                      (list (string-append out scm-dir)
+                      (list (string-append #$output scm-dir)
                             (string-append json scm-dir)
                             (string-append readline scm-dir)))
                      (go-dir (string-append "/lib/guile/" effective
                                             "/site-ccache/"))
-                     (go-path (list (string-append out go-dir)
+                     (go-path (list (string-append #$output go-dir)
                                     (string-append json go-dir)
                                     (string-append readline go-dir))))
-                (wrap-program (string-append out "/bin/dzn")
+                (wrap-program (string-append #$output "/bin/dzn")
                   `("PATH" ":" prefix ,path)
                   `("GUILE_AUTO_COMPILE" ":" = ("0"))
                   `("GUILE_LOAD_PATH" ":" prefix ,scm-path)
