@@ -3,7 +3,7 @@
 // Copyright © 2015, 2016, 2017, 2018, 2019, 2021, 2022, 2023 Rutger van Beusekom <rutger@dezyne.org>
 // Copyright © 2016 Rob Wieringa <rma.wieringa@gmail.com>
 // Copyright © 2016 Henk Katerberg <hank@mudball.nl>
-// Copyright © 2015, 2016, 2017, 2019, 2020, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+// Copyright © 2015, 2016, 2017, 2019, 2020, 2022, 2023 Janneke Nieuwenhuizen <janneke@gnu.org>
 //
 // This file is part of dzn-runtime.
 //
@@ -32,6 +32,7 @@
 #include <algorithm>
 #include <cassert>
 #include <iterator>
+#include <thread>
 
 namespace dzn
 {
@@ -107,7 +108,7 @@ namespace dzn
   , paused(false)
   , current_coroutine(0)
   , switch_context()
-  , task(std::async(std::launch::async, std::ref(*this)))
+  , task(dzn::thread::defer(std::ref(*this)))
   {}
   pump::~pump()
   {
